/*****************************************************************************

  Harmony

  Displays a musical Consonance and a Dissonance in two separate Plots.

  $Name: Funplot_v10 $
  $Revision: 1.1 $
  $Date: 2006/03/02 20:09:05 $

  Copyright (C) 1998-2006 Domenico Reggio, Software-Engineering.

*****************************************************************************/

#include "Funplot.h"
#include <math.h>


int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                   LPSTR lpszCmdLine, int nCmdShow)
{
  // Register the Funplot window class
  Funplot::ClassRegister(hInstance, hPrevInstance, nCmdShow);

  // Program variables
  double f,ome1,ome2a,ome2b,ome3a,ome3b,musiCon,pi,t,amp;

  // Instantiation of the first Funplot window
  Funplot Consonance("Consonance");
  Consonance.SetLables("time [s]","amplitude [-]","Visualisation of a Consonance");
  Consonance.SetNumGraphs(1);
  Consonance.SetRange(-0.05,1.05,-4.1,4.1);
  Consonance.SetAutoWindow(2,1,1);
  Consonance.ShowGraphPoints(HIDE);
  Consonance.SetGraphLineWidth(3);
  Consonance.SetGraphColorNum(2);
  Consonance.Rise();

  // Instantiation of the second Funplot window
  Funplot Dissonance("Dissonance");
  Dissonance.SetLables("time [s]","amplitude [-]","Visualisation of a Dissonance");
  Dissonance.SetNumGraphs(1);
  Dissonance.SetRange(-0.05,1.05,-4.1,4.1);
  Dissonance.SetAutoWindow(2,1,2);
  Dissonance.ShowGraphPoints(HIDE);
  Dissonance.SetGraphLineWidth(3);
  Dissonance.SetGraphColorNum(3);
  Dissonance.Rise();

  // Definition of Pi
  pi= 3.1415926;

  // Definition of the "Musical Constant"
  musiCon= pow(2,1/12.);

  // Frequencies of a Consonance and a Dissonance
  f= 880;                          // Base frequency [Hz]
  ome1= 2*pi*f*pow(musiCon,2.);

  ome2a= 2*pi*f*pow(musiCon,3.);
  ome3a= 2*pi*f*pow(musiCon,5.);   // Consonance

  ome2b= 2*pi*f*pow(musiCon,2.9);
  ome3b= 2*pi*f*pow(musiCon,4.8);  // Dissonance


  // Superimposition of these frequencies as function of time
  for (t=0; t<=1; t+=0.00001) {

    // ... for a Consonance
    amp= sin(ome1*t) + sin(ome2a*t) + sin(ome3a*t);
    Consonance.LineTo(t,amp);

    // ... for a Dissonance
    amp= sin(ome1*t) + sin(ome2b*t) + sin(ome3b*t);
    Dissonance.LineTo(t,amp);

    // Allow user interaction
    Funplot::MessageCheck();

  }

  // Enter the 'endless' message loop until the user exits
  Funplot::MessageLoop();

  return 0;
}
